package jp.co.argo21.nautica.workflow.soap;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.xml.ws.RequestWrapper;
import javax.xml.ws.ResponseWrapper;

import jp.co.argo21.nautica.workflow.omg.WorkflowException;
import jp.co.argo21.nautica.workflow.soap.message.Organization;
import jp.co.argo21.nautica.workflow.soap.message.Role;
import jp.co.argo21.nautica.workflow.soap.message.User;

@WebService(name="RoleManager",
        targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
public interface RoleManager {

	/**
	 * ridに対応する権限を返す。
	 *
	 * @param rid 権限ID
	 * @return 権限
	 * @throws ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@WebMethod(operationName = "getRole")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getRole", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetRole")
	@ResponseWrapper(localName = "getRoleResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetRoleResponse")   
	public Role getRole(@WebParam(name = "rid") String rid) throws ServiceAccessorException, WorkflowException;
	
	/**
	 * 組織に付与されている全権限を返す。
	 *
	 * @param org 組織単位
	 * @return 権限の一覧
	 * @throws ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@WebMethod(operationName = "getAttachedRoles1")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getAttachedRoles1", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetAttachedRoles1")
	@ResponseWrapper(localName = "getAttachedRolesResponse1", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetAttachedRolesResponse1")   
	public Role[] getAttachedRoles(@WebParam(name = "org") Organization org) throws ServiceAccessorException, WorkflowException;
	
	/**
	 * ユーザに付与されている全権限を返す。
	 *
	 * @param user ユーザ
	 * @return 権限の一覧
	 * @throws ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@WebMethod(operationName = "getAttachedRoles2")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getAttachedRoles2", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetAttachedRoles2")
	@ResponseWrapper(localName = "getAttachedRolesResponse2", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetAttachedRolesResponse2")   
	public Role[] getAttachedRoles(@WebParam(name = "user") User user) throws ServiceAccessorException, WorkflowException;
	
	/**
	 * 権限を持つ全組織単位を返す。
	 *
	 * @param role 権限
	 * @return 組織単位の一覧
	 * @throws ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@WebMethod(operationName = "getOrganizationsByRole")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getOrganizationsByRole", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetOrganizationsByRole")
	@ResponseWrapper(localName = "getOrganizationsByRoleResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetOrganizationsByRoleResponse")   
	public Organization[] getOrganizationsByRole(@WebParam(name = "role") Role role) throws ServiceAccessorException, WorkflowException;
	
	/**
	 * 権限を持つ全ユーザを返す。
	 *
	 * @param role 権限
	 * @return ユーザの一覧
	 * @throws ServiceAccessorException 通信障害等によりワークフローエンジンと接続できない場合
	 * @throws WorkflowException 
	 */
	@WebMethod(operationName = "getUsersByRole")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "getUsersByRole", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetUsersByRole")
	@ResponseWrapper(localName = "getUsersByRoleResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.GetUsersByRoleResponse")   
	public User[] getUsersByRole(@WebParam(name = "role") Role role) throws ServiceAccessorException, WorkflowException;
	
}